/**********************************************************************

	Command:  PLOTOPT -- Plot Option Setup Dialog

	Programmed by Kang, Hsin-Min.
	Released at Jul 05, 1997
	Revised at Feb 05, 1998 -- Change "Suppress frame" to "Add Frame"
				   Add Help Button
				   Add Transmission Control group
				   Add "Suppress Print Dialog" option
	Revised at Apr 22, 1998 Include Japenese Text in SJIS codes
	Revised at Aug 05, 1998 Modify Japenese Messages.
	Revised at Aug 21, 1998 Fix a bug in UpdateDialog()

	Copyright (c) 1997, 1998 TCAM Development House, Taipei
	All rights Reserved.

	Status: Standard Command, with full support.

	The following options are setup by this commands:

	Plot/PRPLOT option
	MAXPVANG/MAXPVLEN
	PlotWaitOver
	PlotQueueSize
	DirectPrint
***********************************************************************/
//
//	Flags used in this program for plotoption
//
#define ENDPSWAP_OPT	1	/* End point swap option */
#define PENWIDTHCOMP	2	/* Pen width compensation on fill area */
#define DIRECT_HATCH	0x80	/* Direct Hatch */
#define XOFF_SOUND	0x40
#define SOLIDFRAMEOFF	0x8000
#define SOLIDTHINFRAME	0x4000
#define AUTOSETFRAME	0x1000

#define MARKON	0x8000
#define MARKOFF 0x80ff

#define GENERAL 	"General Setup"
#define DIRECTPRINT	"DirectPrint"
#define PLOTWAITOVER	"PlotWaitOver"
#define PLOTQUEUESIZE	"PlotQueueSize"

int	IsWin;
int	nSupport=identify("wnd_resize");
// Certain functions are supported only in Windows version and after
// wnd_resize(), so checking this will help to identify these supports.
//
//	Copy System variables to local variable for editing
//
int	plotoption=@plotoption;
double	maxpvang=@maxpvang;
double	maxpvlen=@maxpvlen;
//
//	DOS version does not support get_profile() ...
//
int	nDirect; // =eval(get_profile(GENERAL,DIRECTPRINT)+"+0");
int	nWait;	 // =eval(get_profile(GENERAL,PLOTWAITOVER)+"+0");
int	nQueue;  // =eval(get_profile(GENERAL,PLOTQUEUESIZE)+"+0");
//
int	nMain[6]={3,24,10,72,0x3270,0x8000};
int	widMain;	// Main Dialog Window ID
int	nTatrb=0x2f0;
int	nSatrb=0x270;
int	bEndp;		// End point swapping
int	bUDir;		// Unidirectional hatching
int	bMaxA;		// Max. Angle
int	bMaxL;		// Max. Length
int	bDoFrame=-99;	// Initialize for Dos Version
int	bFrame0=-99;
int	bFrame1=-99;
int	bProc0=-99;
int	bProc1=-99;
int	bDirect=-99;
int	bQueue=-99;
int	bWait=-99;

int	bOK;		// General Ok button
int	bCancel;	// General Cancel button
int	bHelp;		// General Help button

char	szBtn[10][10];	// For all common buttons (8 chars)
char	szText[20][40]; // Our display text buffer, see SetMsgText()
			// at the end of this file

// Macro to update variable with Undo consideration.
#define savevar(name)	if (name!=@name) { set_undo("name"); @name=name;}

COMMAND PlotOpt()
{
	IsWin = 1;
	switch(1) {  // Test if we are in TwinCAD ...
	  case !identify("os_type"):
	  case (os_type()<0):	// Must be in DOS version!
		IsWin = 0;
		break;
	}

	if ( !IsWin ) nMain[1] = 18;
	else {
		nDirect=eval(get_profile(GENERAL,DIRECTPRINT)+"+0");
		nWait  =eval(get_profile(GENERAL,PLOTWAITOVER)+"+0");
		nQueue =eval(get_profile(GENERAL,PLOTQUEUESIZE)+"+0");
		if ( nQueue == 0 ) nQueue = 8192;
	}

	SetMsgText();
	if ( DoPlotOpt() ) {	// Ok, update these variables
		savevar(plotoption);
		savevar(maxpvang);
		savevar(maxpvlen);
		if ( IsWin ) {
			set_profile(GENERAL,DIRECTPRINT,prints("%d",nDirect));
			set_profile(GENERAL,PLOTWAITOVER,prints("%d",nWait));
			if ( nQueue )
				set_profile(GENERAL,PLOTQUEUESIZE,prints("%u",nQueue));
		}
	}
}

int	DoPlotOpt()
{
	int	nBtn;
	int	which;
	long	lval;

	OpenDialog();
	UpdateDialog();
	for(;;) {
		nBtn = wnd_gbtn(0);
		switch(nBtn) {
		  case -3:
		  case -2:
		  case -1:
		  case	0:
			CloseDialog();
			return 0;
		  case bEndp:
			plotoption ^= ENDPSWAP_OPT;
			wnd_fmark(bEndp,0,(plotoption&ENDPSWAP_OPT)?MARKON:MARKOFF);
			continue;
		  case bUDir:
			plotoption ^= DIRECT_HATCH;
			wnd_fmark(bUDir,0,(plotoption&DIRECT_HATCH)?MARKON:MARKOFF);
			continue;
		  case bMaxA:
			maxpvang = dtr(wnd_fgetd(bMaxA,8,0x2e0,rtd(maxpvang)));
			wnd_ftext(bMaxA,prints("%8.3f",rtd(maxpvang)),0x2f0);
			continue;
		  case bMaxL:
			maxpvlen = wnd_fgetd(bMaxL,8,0x2e0,maxpvlen);
			wnd_ftext(bMaxL,prints("%8.3f",maxpvlen),0x2f0);
			continue;
		  case bDoFrame:
			plotoption ^= SOLIDFRAMEOFF;
			wnd_fmark(bDoFrame,0,!(plotoption&SOLIDFRAMEOFF)?MARKON:MARKOFF);
			if ( identify("wnd_state") ) {
			    if ( (plotoption&SOLIDFRAMEOFF) ) {
				wnd_state(bFrame0,1,1);
				wnd_state(bFrame1,1,1);
			    }
			    else {
				wnd_state(bFrame0,1,0);
				wnd_state(bFrame1,1,0);
			    }
			}
			continue;
		  case bFrame0:
			plotoption &= ~SOLIDTHINFRAME;
			wnd_fmark(bFrame0,1,(!(plotoption&SOLIDTHINFRAME))?MARKON:MARKOFF);
			wnd_fmark(bFrame1,1,(plotoption&SOLIDTHINFRAME)?MARKON:MARKOFF);
			continue;
		  case bFrame1:
			plotoption |= SOLIDTHINFRAME;
			wnd_fmark(bFrame0,1,(!(plotoption&SOLIDTHINFRAME))?MARKON:MARKOFF);
			wnd_fmark(bFrame1,1,(plotoption&SOLIDTHINFRAME)?MARKON:MARKOFF);
			continue;
		  case bProc0:
			plotoption &= ~AUTOSETFRAME;
			wnd_fmark(bProc0,1,(!(plotoption&AUTOSETFRAME))?MARKON:MARKOFF);
			wnd_fmark(bProc1,1,((plotoption&AUTOSETFRAME))?MARKON:MARKOFF);
			continue;
		  case bProc1:
			plotoption |= AUTOSETFRAME;
			wnd_fmark(bProc0,1,(!(plotoption&AUTOSETFRAME))?MARKON:MARKOFF);
			wnd_fmark(bProc1,1,((plotoption&AUTOSETFRAME))?MARKON:MARKOFF);
			continue;
		  case bDirect:
			nDirect = !nDirect;
			wnd_fmark(bDirect,0,nDirect?MARKON:MARKOFF);
			continue;
		  case bWait:
			nWait = !nWait;
			wnd_fmark(bWait,0,nWait?MARKON:MARKOFF);
			continue;
		  case bQueue:
			lval = nQueue;
			nQueue = wnd_fgetd(bQueue,5,0x2e0,lval&0xffffL);
			wnd_ftext(bQueue,prints("%5u",nQueue),0x2f0);
			continue;
		  case bCancel:
			CloseDialog();
			return 0;
		  case bOK:
			CloseDialog();
			return 1;
		  case bHelp:
			show_help("","PLOTOPT");
			continue;
		}
	}
}
//
//	OpenDialog() -- Open main dialog window, create screen items.
//
void	OpenDialog()
{
	int	rBase, cBase, col;
	int	rInc=0x0401;
	widMain = wndopen(nMain,szText[0]/*"Plot Option Setup Dialog"*/,0x3f1f,nMain[5]);
	WndGroup(0x0800,2,44,(IsWin?9:6)|0xf800,szText[1]/*"Plotter Output Options"*/,0x271);
	rBase = 0x0c01;
	cBase = 4;
	bEndp  = WndCheckBox(rBase+rInc*0,cBase,szText[2]/*"End point swapping optimization"*/,nSatrb);
	bUDir  = WndCheckBox(rBase+rInc*1,cBase,szText[3]/*"Solid filled with uni-direction lines"*/,nSatrb);
	rBase += rInc*2;
	WndGroup(rBase,3,42,2|0xf800,szText[4]/*"Chord Segmentation Control"*/,0x270);
	rBase += rInc;
	cBase  = 4;
	bMaxA  = WndEntry(rBase+rInc*0,cBase,szText[5]/*"Max. Angle: "*/,0x108,0);
	col = len(szText[5]/*"Max. Angle: "*/)+9;
	bMaxL  = WndEntry(rBase+rInc*0,cBase+col,szText[6]/*"  Length: "*/,0x108,0);
    if ( IsWin ) {
	rBase += rInc+0x0800;
	WndGroup(rBase,3,42,2|0xf800,szText[15]/*"Transmission Control"*/,0x270);
	rBase += rInc;
	bQueue = WndEntry(rBase+rInc*0,cBase,szText[16]/*"Queue Size: "*/,0x105,0);
	col = len(szText[16]/*"Queue Size: "*/)+7;
	bWait  = WndCheckBox(rBase+rInc*0,cBase+col,szText[17]/*"Wait for queue empty"*/,nSatrb);
	rBase += rInc+0x0001;
	WndGroup(rBase,2,44,4|0x0000,szText[7]/*"Printer Output Options"*/,0x271);
	rBase += 0x0401;
	cBase = 4;
	bDoFrame = WndCheckBox(rBase+rInc*0,cBase,szText[8]/*"Add boundary frame over solid area"*/,nSatrb);
	rBase += 0x0001;
	WndGroup(rBase,6,36,2|0xf800,"",0x270);
	rBase += 0x0800;
	cBase = 8;
	bFrame0 = WndRadioBox(rBase	  ,cBase,szText[9]/*"Drawn with specified pen width"*/,nSatrb);
	bFrame1 = WndRadioBox(rBase+0x0201,cBase,szText[10]/*"Drawn with thin line"*/,nSatrb);
	rBase += rInc*2+0x0800;
	cBase = 4;
	WndGroup(rBase,2,58,3|0xf800,szText[11]/*"PRPLOT Command Procedure"*/,0x271);
	rBase += 0x0401;
	bProc0 = WndRadioBox(rBase+rInc*0,cBase,szText[12]/*"Dos version compatible."*/,nSatrb);
	bProc1 = WndRadioBox(rBase+rInc*1,cBase,szText[13]/*"Standard procedure."*/,nSatrb);
	bDirect= WndCheckBox(rBase+rInc*0,cBase+len(szText[12])+4,szText[14],nSatrb);
    }
	rBase = 0x0801;
	cBase = 50;
	bOK	= WndButton(rBase+rInc*0,cBase,0x108,szBtn[0]/*"   OK   "*/);
	bCancel = WndButton(rBase+rInc*2,cBase,0x108,szBtn[1]/*" Cancel "*/);
    if ( IsWin )
	bHelp	= WndButton(rBase+rInc*4,cBase,0x108,szBtn[2]/*"  Help  "*/);
}
//
//	Note:	The use of wnd_fmark to make a check on the checkbox
//		is not fully compatible with DOS version, although
//		the expression: wnd_fmark(n,0,(Check)?MARKON:MARKOFF)
//		still works.
//
void	UpdateDialog()
{
	wnd_fmark(bEndp,0,(plotoption&ENDPSWAP_OPT)?MARKON:MARKOFF);
	wnd_fmark(bUDir,0,(plotoption&DIRECT_HATCH)?MARKON:MARKOFF);
	wnd_ftext(bMaxA,prints("%8.3f",rtd(maxpvang)),0x2f0);
	wnd_ftext(bMaxL,prints("%8.3f",maxpvlen),0x2f0);

    if ( IsWin ) {
	wnd_fmark(bDoFrame,0,!(plotoption&SOLIDFRAMEOFF)?MARKON:MARKOFF);
	wnd_fmark(bFrame0,1,(!(plotoption&SOLIDTHINFRAME))?MARKON:MARKOFF);
	wnd_fmark(bFrame1,1,(plotoption&SOLIDTHINFRAME)?MARKON:MARKOFF);
	wnd_fmark(bProc0,1,(!(plotoption&AUTOSETFRAME))?MARKON:MARKOFF);
	wnd_fmark(bProc1,1,((plotoption&AUTOSETFRAME))?MARKON:MARKOFF);
	if ( identify("wnd_state") ) {
	    if ( (plotoption&SOLIDFRAMEOFF) ) {
		wnd_state(bFrame0,1,1);
		wnd_state(bFrame1,1,1);
	    }
	    else {
		wnd_state(bFrame0,1,0);
		wnd_state(bFrame1,1,0);
	    }
	}
	wnd_fmark(bDirect,0,nDirect?MARKON:MARKOFF);
	wnd_fmark(bWait,0,nWait?MARKON:MARKOFF);
	wnd_ftext(bQueue,prints("%5u",nQueue),0x2f0);
    }
}
//
//	CloseDialog() -- Close the main dialog window, save window attribute
//
void	CloseDialog()
{
	wndclose();
}
//
//	WndGroup() -- Create Groupping window effect
//
void	WndGroup(int r,int c,int width, int height, char text[], int color)
{
	wnd_loct(r,c);
	wnd_rloct(height,0);
	wnd_field(0,0x277,(height<<8)|width);
	wnd_itemno(1,-1);
	wnd_rloct(-height,2);
	if ( !IsWin )
		wnd_rloct(0xfc00,0);
	put3Dstr(text,color);
	wnd_loct(r,c);	      // Reset row offset, fix DOS version bug
}
//
//	put3Dstr() -- Drawing 3D text
//
void	put3Dstr(char str[],int atrb)
{
	int	nLen;
	if ( nSupport ) {
		wnd_puts(str,atrb|0x300);
		return;
	}
	nLen=len(str);
	if ( nLen ) {
		wnd_rloct(0x100,IsWin?0x100:0);
		wnd_puts(str,(atrb^0x0f));
		wnd_rloct(0xff00,-nLen);
		wnd_puts(str,(atrb&0xff0f)|0x8000);
	}
}
//
//	WndCheckBox() -- Create window check box
//
int	WndCheckBox(int r,int c,char text[],int atrb)
{
	int	bID;
	if ( nSupport )
		return wnd_rcbox(r,c,text,0x4300);
	wnd_loct(r,c);
	bID = wnd_field(1,0x1f0,0x102);
	wnd_rloct(0,2);
	if ( IsWin )  atrb |= 0x800;
	wnd_puts(text,atrb);
	return bID;
}
//
//	WndRadioBox() -- Create window radio box
//
int	WndRadioBox(int r,int c,char text[],int atrb)
{
	int	bID;
	if ( nSupport )
		return wnd_rcbox(r,c,text,0x8000|0x4300);
	wnd_loct(r,c);
	bID = wnd_field(1,0x1f0,0x102);
	wnd_rloct(0,2);
	if ( IsWin ) atrb |= 0x800;
	wnd_puts(text,atrb);
	wnd_fmark(bID,1,IsWin?1:MARKON);     // Force to change state
	wnd_fmark(bID,1,IsWin?0:MARKOFF);
	return bID;
}
//
#define OBM_COMBO	"#32738"
int	WndEntry(int row, int col, char str[],int fsize,int combo)
{
	int	bID;

	wnd_loct(row,col);
	put3Dstr(str,0x270);
	bID = wnd_field(0,IsWin?0x1f0:0x21f0,fsize);
	if ( combo == 1 ) {
	    wnd_rloct(0xfe00,0x0600|(fsize&0xff));
	    if ( IsWin) wnd_runit(12);
	    if ( identify("cb_empty") ) {   // Supported only after this version
		 wnd_icon(1,0xA77,0x101,OBM_COMBO);
		 wnd_runit(-1);
		 wnd_rloct(0x0200,0x0002);  // locate forward
	    }
	    else {
		 wnd_field(0,IsWin?0x277:0x370,0x101);
		 wnd_runit(IsWin?-1:16);
		 wnd_ftext(bID+1,"",IsWin?0x277:0x270);
		 wnd_rloct(0x0200,0x0201);  // locate forward
	    }
	}
	else if ( combo == 2 ) {
	    wnd_rloct(0xf400,0x0600|(fsize&0xff));
	    wnd_runit(6);
	    wnd_field(0,IsWin?0x277:0x370,0x101);
	    wnd_ftext(bID+1,"",IsWin?0x277:0x270);
	    wnd_rloct(0x0e00,0xff);
	    wnd_field(0,IsWin?0x277:0x370,0x101);
	    wnd_ftext(bID+2,"",IsWin?0x277:0x270);
	    wnd_runit(-1);
	    wnd_rloct(0,2);  // locate forward
	}
	return bID;
}
//
int	WndButton(int r,int c, int bsize, char text[])
{
	int	i;
	if ( nSupport ) 	// Having direct support ?
		return wnd_button(r,c,bsize,0x1277,text);
	wnd_loct(r,c);
	i = wnd_field(0,IsWin?0x1277:0x370,bsize);
	wnd_puts(text,0x270);
	return i;
}
//
int	set_profile(char section[], char entry[], char value[])
{
	if ( get_profile(section,entry) != value ) {
		put_profile(section,entry,value);
		return 1;
	}
	return 0;
}

char	szAsciiText[][40]={	    // Default English Display Text
/*  0 */   "Plot Option Setup Dialog",
/*  1 */   "Plotter Output Options",
/*  2 */   "End points swapping optimization",
/*  3 */   "Solid filled with unidirectional lines",
/*  4 */   "Chord Segmentation Control",
/*  5 */   "Max. Angle: ",
/*  6 */   "  Length: ",
/*  7 */   "Printer Output Options",
/*  8 */   "Add boundary frame over solid area",
/*  9 */   "Drawn with specified pen width",
/* 10 */   "Drawn with thin line",
/* 11 */   "PRPLOT Command Procedure",
/* 12 */   "DOS version compatible.",
/* 13 */   "Standard procedure.",
/* 14 */   "Suppress Print Dialog",
/* 15 */   "Transmission Control",
/* 16 */   "Queue Size: ",
/* 17 */   "Wait for queue empty",
};

char	szBig5Text[][40]={	   // Default Chinese Big-5 Display Text
/*  0 */   "øϿX\\ﶵ]w",
/*  1 */   "øϾX]w",
/*  2 */   "̪IǸm̨Τ.",
/*  3 */   "HVˤ覡i߶.",
/*  4 */   "꩷uƩ",
/*  5 */   "̤ji: ",
/*  6 */   "  ̤j: ",
/*  7 */   "tΦLX]w",
/*  8 */   "߶ϰ[.",
/*  9 */   "Hwe[.",
/* 10 */   "H̲ӽu[.",
/* 11 */   "PRPLOT LXϫOާ@{",
/* 12 */   "Dos ªۮeާ@{.",
/* 13 */   "зǾާ@{.",
/* 14 */   "LзǦLܵ",
/* 15 */   "Xwİϱ",
/* 16 */   "wİϤjp: ",
/* 17 */   "Խwİϰe׵",
};

char	szGB2312Text[][40]={	// Default Chinese GB2312 Display Text
/*  0 */   "ͼ\ѡ趨",
/*  1 */   "ʽͼ趨",
/*  2 */   "˵˳û.",
/*  3 */   "Եɨ鷽ʽʵͿɫ.",
/*  4 */   "Բ߻ҳ",
/*  5 */   "Ž: ",
/*  6 */   "  󳤶: ",
/*  7 */   "ϵͳӡ趨",
/*  8 */   "ʵͿɫӿ.",
/*  9 */   "ָʿӿ.",
/* 10 */   "ϸ߼ӿ.",
/* 11 */   "PRPLOT ӡͼָ",
/* 12 */   "Dos ɰݲ.",
/* 13 */   "׼.",
/* 14 */   "Ӵ׼ӡԻ",
/* 15 */   "",
/* 16 */   "С: ",
/* 17 */   "Ⱥ򻺳Ž",
};
//
//	The following Japenese messages are translated by _____________.
//
char	szSJISText[][40]={    // Default Japenese SJIS Display Text
/*  0 */   "ۯEo",
/*  1 */   "vb^[o͂̏ڍאݒ",
/*  2 */   "ۯo͎݂̓̍œK",
/*  3 */   "͓̈h荞",
/*  4 */   "vbgł̍}̌̏ڍאݒ",
/*  5 */   "őp: ",
/*  6 */   "ő咷: ",
/*  7 */   "v^[o͂̏ڍאݒ",
/*  8 */   "Ẽt[o",
/*  9 */   "w肵y̕ō}",
/* 10 */   "ׂyō}",
/* 11 */   "PRPLOT R}h",
/* 12 */   "DOS œ",
/* 13 */   "W̃R}h",
/* 14 */   "vg̏ڍאݒ\\",
/* 15 */   "f[^]",
/* 16 */   "obt@[TCY: ",
/* 17 */   "L[",
};
//
//	The following Korean messages are translated by _____________.
//
char	szKoreanText[][40]={	// Default Korean Display Text
/*  0 */   "Plot Option Setup Dialog",
/*  1 */   "Plotter Output Options",
/*  2 */   "End points swapping optimization",
/*  3 */   "Solid filled with unidirectional lines",
/*  4 */   "Chord Segmentation Control",
/*  5 */   "Max. Angle: ",
/*  6 */   "  Length: ",
/*  7 */   "Printer Output Options",
/*  8 */   "Add boundary frame over solid area",
/*  9 */   "Drawn with specified pen width",
/* 10 */   "Drawn with thin line",
/* 11 */   "PRPLOT Command Procedure",
/* 12 */   "DOS version compatible",
/* 13 */   "Standard procedure",
/* 14 */   "Suppress Print Dialog",
/* 15 */   "Transmission Control",
/* 16 */   "Queue Size: ",
/* 17 */   "Wait for queue empty",
};

char	szAsciiBtn[][10]={	   // Default English Display Text
/*  0 */   "&OK",
/*  1 */   "&Cancel",
/*  2 */   "&Help",
};

char	szBig5Btn[][10]={	  // Default English Display Text
/*  0 */   "Tw[&O]",
/*  1 */   "[&C]",
/*  2 */   "[&H]",
};

char	szGB2312Btn[][10]={	    // Default English Display Text
/*  0 */   "ȷ[&O]",
/*  1 */   "ȡ[&C]",
/*  2 */   "˵[&H]",
};

char	szSJISBtn[][10]={	  // Default English Display Text
/*  0 */   "&OK",
/*  1 */   "ݾ[&C]",
/*  2 */   "[&H]",
};

char	szKoreanBtn[][10]={	    // Default English Display Text
/*  0 */   "&OK",
/*  1 */   "&Cancel",
/*  2 */   "&Help",
};

char	szDOSAsciiBtn[][10]={	      // Default English Display Text
/*  0 */   "   OK   ",
/*  1 */   " Cancel ",
/*  2 */   "  Help  ",
};

char	szDOSBig5Btn[][10]={	     // Default English Display Text
/*  0 */   "  Tw  ",
/*  1 */   "    ",
/*  2 */   "    ",
};

char	szDOSGB2312Btn[][10]={	       // Default English Display Text
/*  0 */   "  ȷ  ",
/*  1 */   "  ȡ  ",
/*  2 */   "  ˵  ",
};

char	szDOSSJISBtn[][10]={	     // Default English Display Text
/*  0 */   "   OK   ",
/*  1 */   "  ݾ ",
/*  2 */   "    ",
};

char	szDOSKoreanBtn[][10]={	       // Default English Display Text
/*  0 */   "   OK   ",
/*  1 */   " Cancel ",
/*  2 */   "  Help  ",
};

#define BIG5		0x404
#define GB2312		0x804
#define SJIS		0x411
#define KOREAN		0x412
#define ASCII		0x409

#define TGBIG5		1
#define TGGB2312	2
#define TGSJIS		5
#define TGKOREAN	3

int	SetMsgText()
{
	char	szBuf[80];
	int	switched;

	IsWin = 1;
	switch(1) {  // Test if we are in TwinCAD ...
	  case !identify("os_type"):
	  case (os_type()<0):	// Must be in DOS version!
		IsWin = 0;
		break;
	}

	if ( IsWin ) {
	    szBuf = get_profile("General Setup","AlternateLanguage");
	    switched = 0;
	    if ( szBuf!="" )
		switched = eval(szBuf);
	    setdata(szText,szAsciiText);
	    setdata(szBtn,szAsciiBtn);
	    if ( switched ) {
		switch(os_language()) {
		  case BIG5:	setdata(szText,szBig5Text);	break;
		  case GB2312:	setdata(szText,szGB2312Text);	break;
		  case SJIS:	setdata(szText,szSJISText);	break;
		  case KOREAN:	setdata(szText,szKoreanText);	break;
		  default:	setdata(szText,szAsciiText);	break;
		}
		switch(os_language()) {
		  case BIG5:	setdata(szBtn,szBig5Btn);     break;
		  case GB2312:	setdata(szBtn,szGB2312Btn);   break;
		  case SJIS:	setdata(szBtn,szSJISBtn);     break;
		  case KOREAN:	setdata(szBtn,szKoreanBtn);   break;
		  default:	setdata(szBtn,szAsciiBtn);    break;
		}
	    }
	}
	else {	// Switched or not, depends on TGF type in DOS version
	    setdata(szText,szAsciiText);
	    setdata(szBtn,szDOSAsciiBtn);
	    switch(@tgftype) {
	      case TGBIG5:    setdata(szText,szBig5Text);     break;
	      case TGGB2312:  setdata(szText,szGB2312Text);   break;
	      case TGSJIS:    setdata(szText,szSJISText);     break;
	      case TGKOREAN:  setdata(szText,szKoreanText);   break;
	      default:	      setdata(szText,szAsciiText);    break;
	    }
	    switch(@tgftype) {
	      case TGBIG5:    setdata(szBtn,szDOSBig5Btn);     break;
	      case TGGB2312:  setdata(szBtn,szDOSGB2312Btn);   break;
	      case TGSJIS:    setdata(szBtn,szDOSSJISBtn);     break;
	      case TGKOREAN:  setdata(szBtn,szDOSKoreanBtn);   break;
	      default:	      setdata(szBtn,szDOSAsciiBtn);    break;
	    }
	}
	return 0;
}
//
//	End of this Program file
//
